-- M.A.I.D.  (Mining And Inventory Daemon)
--
-- Settings portion of M.A.I.D.
--
-- Assembled and written by igrok
-- Portions adopted from AutoJett v2.3 GUI by iry
-- Some portions taken from TGFT TradeAssistant (TA)
--


MAID.settings.settingID = '624362430'

-- Set to true until settings have been loaded
MAID.settings.initializing = true

function MAID.settings:OnEvent(eventname, ...)
    if MAID.settings.initializing and eventname == 'SECTOR_LOADED' then
        MAID.settings:read()
        MAID.settings.initializing = false

        -- once settings have been loaded, we don't need these events
        UnregisterEvent(MAID.settings, "SECTOR_LOADED")
    elseif not MAID.settings.initializing then
        MAID.settings:save()

        -- reset in case user logs in with another user
        MAID.settings.initializing = true
        RegisterEvent(MAID.settings, "SECTOR_LOADED")
    end
end    


-- Switch between strings ('ON', 'OFF') and boolean values.
function MAID:StrBool(value)
    if type(value) == 'boolean' then
        if value then
            return 'ON'
        else
            return 'OFF'
        end
    elseif type(value) == 'string' then
        if value == 'ON' then
            return true
        else
            return false
        end
    else
        return nil
    end
end


function MAID.settings:save()
    gkini.WriteString('MAID', 'MAID.settings.jettison', MAID:StrBool(MAID.settings.jettison))
    gkini.WriteString('MAID', 'MAID.settings.exclusiveMode', MAID:StrBool(MAID.settings.exclusiveMode))
    gkini.WriteString('MAID', 'MAID.settings.combatMode', MAID:StrBool(MAID.settings.combatMode))
    gkini.WriteString('MAID', 'MAID.settings.tempNotify', MAID:StrBool(MAID.settings.tempNotify))
    gkini.WriteString('MAID', 'MAID.settings.tempSafety', MAID:StrBool(MAID.settings.tempSafety))
    gkini.WriteString('MAID', 'MAID.settings.tempMax', MAID.settings.tempMax)
    gkini.WriteString('MAID', 'MAID.settings.sound', MAID:StrBool(MAID.settings.sound))

    SaveSystemNotes(spickle({cargoItems=MAID.cargoItems}), MAID.settings.settingID)

    MAID:debugPrint('MAID settings saved.')
end


function MAID.settings:read()
    MAID.settings.jettison = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.jettison', 'ON'))
    MAID.settings.exclusiveMode = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.exclusiveMode', 'OFF'))
    MAID.settings.combatMode = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.combatMode', 'OFF'))
    MAID.settings.tempNotify = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.tempNotify', 'ON'))
    MAID.settings.tempSafety = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.tempSafety', 'OFF'))
    MAID.settings.tempMax = tonumber(gkini.ReadString('MAID', 'MAID.settings.tempMax', '100'))
    MAID.settings.sound = MAID:StrBool(gkini.ReadString('MAID', 'MAID.settings.sound', 'OFF'))

    MAID.cargoItems = {}
    local load = unspickle(LoadSystemNotes(MAID.settings.settingID))
    MAID.cargoItems = load.cargoItems or {}

    -- If no cargo items were saved, we'll load some defaults.
    -- {Name, Jettison?, Quantity Dropped, Quantity Collected}
    if next(MAID.cargoItems) == nil then
        MAID:debugPrint('No cargo items saved - loading defaults.')

        local defaults = {
            ['Premium Aquean Ore'] = 'ON',
            ['Premium Silicate Ore'] = 'ON',
            ['Premium Carbonic Ore'] = 'ON',
            ['Premium Ferric Ore'] = 'ON',
            ['Premium Ishik Ore'] = 'ON',
            ['Premium VanAzek Ore'] = 'ON',
            ['Premium Xithricite Ore'] = 'OFF',
            ['Lanthanic Ore'] = 'OFF',
            ['Denic Ore'] = 'OFF',
            ['Pyronic Ore'] = 'OFF',
            ['Apicene Ore'] = 'OFF',
            ['Pentric Ore'] = 'OFF',
            ['Heliocene Ore'] = 'OFF',
            ['Scrap Metal'] = 'ON',
        }

        for k,v in pairs(defaults) do
            local item = {}
            item.Name = k
            item.Jettison = MAID:StrBool(v)
            item.Dropped = 0
            item.Collected = 0

            table.insert(MAID.cargoItems, item)
        end

    -- go through cargo items to reset the dropped/collected stats
    else
        for i,item in ipairs(MAID.cargoItems) do
            MAID.cargoItems[i].Dropped = 0
            MAID.cargoItems[i].Collected = 0
        end
    end

    MAID:debugPrint('MAID settings loaded.')
end


RegisterEvent(MAID.settings, "SECTOR_LOADED")
RegisterEvent(MAID.settings, 'PLAYER_LOGGED_OUT')
RegisterEvent(MAID.settings, 'UNLOAD_INTERFACE')
RegisterEvent(MAID.settings, 'SERVER_DISCONNECTED')

